@@ -1,6 +1,6 @@
 /*
 	Actiona
-	Copyright (C) 2005-2016 Jonathan Mercier-Ganady
+	Copyright (C) 2005 Jonathan Mercier-Ganady
 
 	Actiona is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
 
 namespace Actions
 {
-	ActionTools::StringListPair ReadEnvironmentVariableInstance::modes = qMakePair(
+    Tools::StringListPair ReadEnvironmentVariableInstance::modes = qMakePair(
 			QStringList() << "allVariables" << "oneVariable",
             QStringList() << QT_TRANSLATE_NOOP("ReadEnvironmentVariableInstance::modes", "Read all") << QT_TRANSLATE_NOOP("ReadEnvironmentVariableInstance::modes", "Read one"));
 
