@@ -1,6 +1,6 @@
 /*
 	Actiona
-	Copyright (C) 2005-2016 Jonathan Mercier-Ganady
+	Copyright (C) 2005 Jonathan Mercier-Ganady
 
 	Actiona is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -36,7 +36,7 @@
 
 namespace Actions
 {
-    ActionTools::StringListPair SendMailInstance::attachmentContentTypes = qMakePair(
+    Tools::StringListPair SendMailInstance::attachmentContentTypes = qMakePair(
             QStringList() << "autoDetect" << "application/octet-stream" << "text/plain" << "image/jpeg" << "image/png",
             QStringList() << QT_TRANSLATE_NOOP("SendMailInstance::attachmentContentTypes", "Auto detect")
                           << QT_TRANSLATE_NOOP("SendMailInstance::attachmentContentTypes", "Binary")
@@ -49,7 +49,6 @@ namespace Actions
           mSmtp(nullptr),
 		  mProgressDialog(new QProgressDialog)
 	{
-		connect(mProgressDialog, SIGNAL(canceled()), this, SLOT(canceled()));
 	}
 
     SendMailInstance::~SendMailInstance()
@@ -134,6 +133,8 @@ namespace Actions
         connect(mSmtp, SIGNAL(mailSent(int)), this, SLOT(mailSent(int)));
         connect(mSmtp, SIGNAL(disconnected()), this, SLOT(disconnected()));
 
+        connect(mProgressDialog, SIGNAL(canceled()), this, SLOT(canceled()));
+
         mSmtp->setUsername(userName.toUtf8());
         mSmtp->setPassword(password.toUtf8());
 
@@ -372,8 +373,10 @@ namespace Actions
 
     void SendMailInstance::cleanup()
     {
+        mSmtp->disconnect();
         mSmtp->disconnectFromHost();
 
+        mProgressDialog->disconnect();
         mProgressDialog->close();
     }
 }
