@@ -1,6 +1,6 @@
 /*
 	Actiona
-	Copyright (C) 2005-2016 Jonathan Mercier-Ganady
+	Copyright (C) 2005 Jonathan Mercier-Ganady
 
 	Actiona is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -53,7 +53,7 @@ namespace Actions
         SendMailInstance(const ActionTools::ActionDefinition *definition, QObject *parent = 0);
         ~SendMailInstance();
 
-        static ActionTools::StringListPair attachmentContentTypes;
+        static Tools::StringListPair attachmentContentTypes;
 
 		void startExecution();
 		void stopExecution();
