@@ -1,6 +1,6 @@
 /*
 	Actiona
-	Copyright (C) 2005-2016 Jonathan Mercier-Ganady
+	Copyright (C) 2005 Jonathan Mercier-Ganady
 
 	Actiona is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -53,7 +53,7 @@ namespace Actions
 		WebDownloadInstance(const ActionTools::ActionDefinition *definition, QObject *parent = 0);
 		~WebDownloadInstance();
 
-		static ActionTools::StringListPair destinations;
+        static Tools::StringListPair destinations;
 
 		void startExecution();
 		void stopExecution();
