@@ -1,6 +1,6 @@
 /*
 	Actiona
-	Copyright (C) 2005-2016 Jonathan Mercier-Ganady
+	Copyright (C) 2005 Jonathan Mercier-Ganady
 
 	Actiona is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -162,7 +162,7 @@ namespace Code
 		if(RegQueryValueEx(mHKey, wideValue.c_str(), 0, &type, 0, &size) != ERROR_SUCCESS)
 		{
 			throwError("FindValueError", tr("Cannot find the value to read"));
-			return QVariant();
+            return {};
 		}
 	
 		switch(type)
@@ -174,7 +174,7 @@ namespace Code
 				if(RegQueryValueEx(mHKey, wideValue.c_str(), 0, 0, reinterpret_cast<LPBYTE>(&value), &size) != ERROR_SUCCESS)
 				{
 					throwError("FindValueError", tr("Cannot find the value to read"));
-					return QVariant();
+                    return {};
 				}
 	
 				if(type == REG_DWORD_BIG_ENDIAN)
@@ -188,44 +188,36 @@ namespace Code
 		case REG_LINK:
 		case REG_MULTI_SZ:
 			{
-				wchar_t *buffer = new wchar_t[size];
-				if(RegQueryValueEx(mHKey, wideValue.c_str(), 0, 0, reinterpret_cast<LPBYTE>(buffer), &size) != ERROR_SUCCESS)
+                std::vector<wchar_t> buffer(size);
+                if(RegQueryValueEx(mHKey, wideValue.c_str(), 0, 0, reinterpret_cast<LPBYTE>(buffer.data()), &size) != ERROR_SUCCESS)
 				{
 					throwError("FindValueError", tr("Cannot find the value to read"));
-					return QVariant();
+                    return {};
 				}
 	
 				if(type == REG_MULTI_SZ)
 				{
-					QStringList stringList = QString::fromWCharArray(buffer, size / 2).split(QChar(L'\0'), QString::SkipEmptyParts);
-					delete [] buffer;
-	
+                    QStringList stringList = QString::fromWCharArray(buffer.data(), size / 2).split(QChar(L'\0'), QString::SkipEmptyParts);
+
 					if(stringList.last().isEmpty())
 						stringList.removeLast();
 	
 					return stringList;
 				}
 				else
-				{
-					QString back = QString::fromWCharArray(buffer, size / 2);
-					delete [] buffer;
-	
-					return back;
-	
-				}
+                    return QString::fromWCharArray(buffer.data(), size / 2);
 			}
 			break;
 		case REG_BINARY:
 			{
-				char *buffer = new char[size];
-				if(RegQueryValueEx(mHKey, wideValue.c_str(), 0, 0, reinterpret_cast<LPBYTE>(buffer), &size) != ERROR_SUCCESS)
+                std::vector<char> buffer(size);
+                if(RegQueryValueEx(mHKey, wideValue.c_str(), 0, 0, reinterpret_cast<LPBYTE>(buffer.data()), &size) != ERROR_SUCCESS)
 				{
 					throwError("FindValueError", tr("Cannot find the value to read"));
-					return QVariant();
+                    return {};
 				}
 	
-				QByteArray back = QByteArray::fromRawData(buffer, size);
-				delete [] buffer;
+                QByteArray back = QByteArray::fromRawData(buffer.data(), size);
 	
 				return back;
 			}
@@ -236,7 +228,7 @@ namespace Code
 				if(RegQueryValueEx(mHKey, wideValue.c_str(), 0, 0, reinterpret_cast<LPBYTE>(&value), &size) != ERROR_SUCCESS)
 				{
 					throwError("FindValueError", tr("Cannot find the value to read"));
-					return QVariant();
+                    return {};
 				}
 	
 				return value;
@@ -245,7 +237,7 @@ namespace Code
 		case REG_NONE:
 		default:
 			throwError("InvalidValueError", tr("Invalid value type"));
-			return QVariant();
+            return {};
 			break;
 		}
 	#else
@@ -265,13 +257,13 @@ namespace Code
 		if(RegQueryInfoKey(mHKey, 0, 0, 0, 0, 0, 0, &valueCount, &maxValueNameLength, 0, 0, 0) != ERROR_SUCCESS)
 		{
 			throwError("InvalidKeyError", tr("Unable to query informations about this key"));
-			return QStringList();
+            return {};
 		}
 	
 		if(valueCount == 0 || maxValueNameLength == 0)
-			return QStringList();
-	
-		wchar_t *valueName = new wchar_t[maxValueNameLength + 1];
+            return {};
+
+        std::vector<wchar_t> valueName(maxValueNameLength + 1);
 		int result;
 		QStringList back;
 	
@@ -279,21 +271,19 @@ namespace Code
 		{
 			DWORD valueNameSize = maxValueNameLength + 1;
 	
-			result = RegEnumValue(mHKey, index, valueName, &valueNameSize, 0, 0, 0, 0);
+            result = RegEnumValue(mHKey, index, valueName.data(), &valueNameSize, 0, 0, 0, 0);
 			if(result == ERROR_NO_MORE_ITEMS)
 				break;
 	
 			if(valueNameSize == 0)
 				continue;//Skip the default value
 	
-			back.append(QString::fromWCharArray(valueName, valueNameSize));
+            back.append(QString::fromWCharArray(valueName.data(), valueNameSize));
 		}
 	
-		delete [] valueName;
-	
 		return back;
 	#else
-		return QStringList();
+        return {};
 	#endif
 	}
 	
@@ -307,13 +297,13 @@ namespace Code
 		if(RegQueryInfoKey(mHKey, 0, 0, 0, &subKeyCount, &maxSubKeyNameLength, 0, 0, 0, 0, 0, 0) != ERROR_SUCCESS)
 		{
 			throwError("InvalidKeyError", tr("Unable to query informations about this key"));
-			return QStringList();
+            return {};
 		}
 	
 		if(subKeyCount == 0 || maxSubKeyNameLength == 0)
-			return QStringList();
+            return {};
 	
-		wchar_t *subKeyName = new wchar_t[maxSubKeyNameLength + 1];
+        std::vector<wchar_t> subKeyName(maxSubKeyNameLength + 1);
 		int result;
 		QStringList back;
 	
@@ -321,18 +311,16 @@ namespace Code
 		{
 			DWORD subKeyNameSize = maxSubKeyNameLength + 1;
 	
-			result = RegEnumKeyEx(mHKey, index, subKeyName, &subKeyNameSize, 0, 0, 0, 0);
+            result = RegEnumKeyEx(mHKey, index, subKeyName.data(), &subKeyNameSize, 0, 0, 0, 0);
 			if(result == ERROR_NO_MORE_ITEMS)
 				break;
 	
-			back.append(QString::fromWCharArray(subKeyName, subKeyNameSize));
+            back.append(QString::fromWCharArray(subKeyName.data(), subKeyNameSize));
 		}
-	
-		delete [] subKeyName;
-	
+
 		return back;
 	#else
-		return QStringList();
+        return {};
 	#endif
 	}
 	
