@@ -1,6 +1,6 @@
 /*
 	Actiona
-	Copyright (C) 2005-2016 Jonathan Mercier-Ganady
+	Copyright (C) 2005 Jonathan Mercier-Ganady
 
 	Actiona is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -26,20 +26,21 @@
 
 namespace Actions
 {
-	ActionTools::StringListPair ClickInstance::buttons = qMakePair(
+    Tools::StringListPair ClickInstance::buttons = qMakePair(
 			QStringList() << "left" << "middle" << "right",
 			QStringList() << QT_TRANSLATE_NOOP("ClickInstance::buttons", "Left") << QT_TRANSLATE_NOOP("ClickInstance::buttons", "Middle") << QT_TRANSLATE_NOOP("ClickInstance::buttons", "Right"));
-	ActionTools::StringListPair ClickInstance::actions = qMakePair(
+    Tools::StringListPair ClickInstance::actions = qMakePair(
 			QStringList() << "pressRelease" << "press" << "release",
 			QStringList() << QT_TRANSLATE_NOOP("ClickInstance::actions", "Click (press and release)") << QT_TRANSLATE_NOOP("ClickInstance::actions", "Press") << QT_TRANSLATE_NOOP("ClickInstance::actions", "Release"));
 	
 	void ClickInstance::startExecution()
 	{
 		bool ok = true;
+        bool isPositionEmpty = false;
 	
 		Action action = evaluateListElement<Action>(ok, actions, "action", "value");
 		MouseDevice::Button button = evaluateListElement<MouseDevice::Button>(ok, buttons, "button", "value");
-		QPoint position        = evaluatePoint(ok, "position");
+        QPoint position = evaluatePoint(ok, "position", "value", &isPositionEmpty);
 		QPoint positionOffset = evaluatePoint(ok, "positionOffset");
 		int amount = evaluateInteger(ok, "amount");
 	
@@ -56,8 +57,11 @@ namespace Actions
 			return;
 		}
 		
-		position += positionOffset;
-		mMouseDevice.setCursorPosition(position);
+        if(!isPositionEmpty)
+        {
+            position += positionOffset;
+            mMouseDevice.setCursorPosition(position);
+        }
 	
 		for(int i = 0; i < amount; ++i)
 		{
