@@ -1,6 +1,6 @@
 /*
 	Actiona
-	Copyright (C) 2005-2016 Jonathan Mercier-Ganady
+	Copyright (C) 2005 Jonathan Mercier-Ganady
 
 	Actiona is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -47,8 +47,8 @@ namespace Actions
 		ClickInstance(const ActionTools::ActionDefinition *definition, QObject *parent = 0)
 			: ActionTools::ActionInstance(definition, parent)										{}
 	
-		static ActionTools::StringListPair buttons;
-		static ActionTools::StringListPair actions;
+        static Tools::StringListPair buttons;
+        static Tools::StringListPair actions;
 	
 		void startExecution();
 		void stopLongTermExecution();
