@@ -1,6 +1,6 @@
 /*
 	Actiona
-	Copyright (C) 2005-2016 Jonathan Mercier-Ganady
+	Copyright (C) 2005 Jonathan Mercier-Ganady
 
 	Actiona is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -50,7 +50,7 @@ namespace Actions
 			connect(&mMoveTimer, SIGNAL(timeout()), this, SLOT(moveToNextPosition()));
 		}
 
-        static ActionTools::StringListPair buttons;
+        static Tools::StringListPair buttons;
 
 		void startExecution()
 		{
