@@ -1,6 +1,6 @@
 /*
 	Actiona
-	Copyright (C) 2005-2016 Jonathan Mercier-Ganady
+	Copyright (C) 2005 Jonathan Mercier-Ganady
 
 	Actiona is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -53,8 +53,8 @@ namespace Actions
 
 		KeyInstance(const ActionTools::ActionDefinition *definition, QObject *parent = 0);
 		
-		static ActionTools::StringListPair actions;
-		static ActionTools::StringListPair types;
+        static Tools::StringListPair actions;
+        static Tools::StringListPair types;
 
 		void startExecution();
 		void stopExecution();
