@@ -1,6 +1,6 @@
 /*
 	Actiona
-	Copyright (C) 2005-2016 Jonathan Mercier-Ganady
+    Copyright (C) 2005 Jonathan Mercier-Ganady
 
 	Actiona is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -49,7 +49,7 @@ namespace Actions
 			connect(&mCheckTimer, SIGNAL(timeout()), this, SLOT(checkTime()));
 		}
 
-		static ActionTools::StringListPair units;
+        static Tools::StringListPair units;
 
 		void startExecution()
 		{
