@@ -1,6 +1,6 @@
 /*
 	Actiona
-	Copyright (C) 2005-2016 Jonathan Mercier-Ganady
+    Copyright (C) 2005 Jonathan Mercier-Ganady
 
 	Actiona is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -161,7 +161,7 @@ namespace Actions
 			emit executionEnded();
 		}
 
-		static ActionTools::StringListPair comparisons;
+        static Tools::StringListPair comparisons;
 
 	private:
 		Q_DISABLE_COPY(VariableConditionInstance)
