@@ -1,6 +1,6 @@
 /*
 	Actiona
-	Copyright (C) 2005-2016 Jonathan Mercier-Ganady
+    Copyright (C) 2005 Jonathan Mercier-Ganady
 
 	Actiona is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -65,8 +65,8 @@ namespace Actions
 		FindImageInstance(const ActionTools::ActionDefinition *definition, QObject *parent = 0);
 		~FindImageInstance();
 
-		static ActionTools::StringListPair sources;
-        static ActionTools::StringListPair methods;
+        static Tools::StringListPair sources;
+        static Tools::StringListPair methods;
 
 		void startExecution();
         void stopExecution();
