@@ -1,6 +1,6 @@
 /*
 	Actiona
-	Copyright (C) 2005-2016 Jonathan Mercier-Ganady
+    Copyright (C) 2005 Jonathan Mercier-Ganady
 
 	Actiona is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
 
 namespace Actions
 {
-	ActionTools::StringListPair SystemInstance::operations = qMakePair(
+    Tools::StringListPair SystemInstance::operations = qMakePair(
 			QStringList() << "logout" << "reboot" << "shutdown" << "suspend" << "hibernate" << "lockscreen" << "startscreensaver",
 			QStringList()
 			<< QT_TRANSLATE_NOOP("SystemInstance::operations", "Logout")
