@@ -1,6 +1,6 @@
 /*
 	Actiona
-	Copyright (C) 2005-2016 Jonathan Mercier-Ganady
+    Copyright (C) 2005 Jonathan Mercier-Ganady
 
 	Actiona is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -51,8 +51,8 @@ namespace Actions
 		SystemInstance(const ActionTools::ActionDefinition *definition, QObject *parent = 0)
 			: ActionTools::ActionInstance(definition, parent) {}
 
-		static ActionTools::StringListPair operations;
-		static ActionTools::StringListPair modes;
+        static Tools::StringListPair operations;
+        static Tools::StringListPair modes;
 
 		void startExecution();
 
