@@ -1,6 +1,6 @@
 /*
 	Actiona
-    Copyright (C) 2005-2016 Jonathan Mercier-Ganady
+    Copyright (C) 2005 Jonathan Mercier-Ganady
 
 	Actiona is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -31,14 +31,14 @@
 
 namespace Actions
 {
-	ActionTools::StringListPair DataInputInstance::dataTypes = qMakePair(
+    Tools::StringListPair DataInputInstance::dataTypes = qMakePair(
 		QStringList() << "text" << "integer" << "decimal",
 		QStringList()
 		<< QT_TRANSLATE_NOOP("DataInputInstance::dataTypes", "Text")
 		<< QT_TRANSLATE_NOOP("DataInputInstance::dataTypes", "Integer")
 		<< QT_TRANSLATE_NOOP("DataInputInstance::dataTypes", "Decimal"));
 
-    ActionTools::StringListPair DataInputInstance::editorTypes = qMakePair(
+    Tools::StringListPair DataInputInstance::editorTypes = qMakePair(
         QStringList() << "line" << "multiline" << "password",
         QStringList()
         << QT_TRANSLATE_NOOP("DataInputInstance::editorTypes", "Line")
@@ -116,14 +116,14 @@ namespace Actions
 		{
 		case IntegerType:
 			mInputDialog->setInputMode(QInputDialog::IntInput);
-			mInputDialog->setIntValue(integerDefaultValue);
 			mInputDialog->setIntRange(std::numeric_limits<int>::min(), std::numeric_limits<int>::max());
+            mInputDialog->setIntValue(integerDefaultValue);
 			break;
 		case DecimalType:
 			mInputDialog->setInputMode(QInputDialog::DoubleInput);
-			mInputDialog->setDoubleValue(decimalDefaultValue);
 			mInputDialog->setDoubleRange(std::numeric_limits<int>::min(), std::numeric_limits<int>::max());
-			mInputDialog->setDoubleDecimals(4);
+            mInputDialog->setDoubleDecimals(4);
+            mInputDialog->setDoubleValue(decimalDefaultValue);
 			break;
 		default:
 			mInputDialog->setInputMode(QInputDialog::TextInput);
