@@ -1,6 +1,6 @@
 /*
 	Actiona
-	Copyright (C) 2005-2016 Jonathan Mercier-Ganady
+    Copyright (C) 2005 Jonathan Mercier-Ganady
 
 	Actiona is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -48,8 +48,8 @@ namespace Actions
 
 		DataInputInstance(const ActionTools::ActionDefinition *definition, QObject *parent = 0);
 
-		static ActionTools::StringListPair dataTypes;
-        static ActionTools::StringListPair editorTypes;
+        static Tools::StringListPair dataTypes;
+        static Tools::StringListPair editorTypes;
 
 		void startExecution();
 		void stopExecution();
