@@ -1,6 +1,6 @@
 /*
 	Actiona
-	Copyright (C) 2005-2016 Jonathan Mercier-Ganady
+    Copyright (C) 2005 Jonathan Mercier-Ganady
 
 	Actiona is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -65,9 +65,9 @@ namespace Actions
 
 		MessageBoxInstance(const ActionTools::ActionDefinition *definition, QObject *parent = 0);
 
-		static ActionTools::StringListPair icons;
-		static ActionTools::StringListPair buttons;
-		static ActionTools::StringListPair textmodes;
+        static Tools::StringListPair icons;
+        static Tools::StringListPair buttons;
+        static Tools::StringListPair textmodes;
 
 		void startExecution();
 		void stopExecution();
