@@ -1,6 +1,6 @@
 /*
 	Actiona
-	Copyright (C) 2005-2016 Jonathan Mercier-Ganady
+    Copyright (C) 2005 Jonathan Mercier-Ganady
 
 	Actiona is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -39,7 +39,7 @@
 
 namespace Actions
 {
-	ActionTools::StringListPair MultiDataInputInstance::modes = qMakePair(
+    Tools::StringListPair MultiDataInputInstance::modes = qMakePair(
 			QStringList() << "comboBox" << "editableComboBox" << "list" << "checkbox" << "radioButton",
 			QStringList()
 			<< QT_TRANSLATE_NOOP("MultiDataInputInstance::modes", "ComboBox")
@@ -142,6 +142,9 @@ namespace Actions
 			break;
 		}
 
+        if(mMode != ListMode)
+            layout->addStretch(1);
+
 		QDialogButtonBox *dialogButtonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, Qt::Horizontal, mDialog);
 		layout->addWidget(dialogButtonBox);
 
