@@ -1,6 +1,6 @@
 /*
 	Actiona
-	Copyright (C) 2005-2016 Jonathan Mercier-Ganady
+    Copyright (C) 2005 Jonathan Mercier-Ganady
 
 	Actiona is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@
 
 namespace Actions
 {
-	ActionTools::StringListPair WindowConditionInstance::conditions = qMakePair(
+    Tools::StringListPair WindowConditionInstance::conditions = qMakePair(
 			QStringList() << "exists" << "dontexists",
 			QStringList()
 			<< QT_TRANSLATE_NOOP("WindowConditionInstance::conditions", "Exists")
