@@ -1,6 +1,6 @@
 /*
 	Actiona
-	Copyright (C) 2005-2016 Jonathan Mercier-Ganady
+    Copyright (C) 2005 Jonathan Mercier-Ganady
 
 	Actiona is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
 
 namespace Actions
 {
-	ActionTools::StringListPair WindowInstance::actions = qMakePair(
+    Tools::StringListPair WindowInstance::actions = qMakePair(
 			QStringList() << "close" << "killProcess" << "setForeground" << "minimize" << "maximize" << "move" << "resize",
 			QStringList()
 			<< QT_TRANSLATE_NOOP("WindowInstance::actions", "Close")
