@@ -1,6 +1,6 @@
 /*
     Actiona
-	Copyright (C) 2005-2016 Jonathan Mercier-Ganady
+	Copyright (C) 2005 Jonathan Mercier-Ganady
 
     Actiona is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -153,7 +153,7 @@ namespace ActionTools
 			return;
 		}
 
-        Tools::installTranslator(QString("actionpack%1").arg(actionPack->id()), locale);
+        Tools::Languages::installTranslator(QString("actionpack%1").arg(actionPack->id()), locale);
 
 		actionPack->createDefinitions();
 
