@@ -1,6 +1,6 @@
 /*
 	Actiona
-	Copyright (C) 2005-2016 Jonathan Mercier-Ganady
+	Copyright (C) 2005 Jonathan Mercier-Ganady
 
 	Actiona is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -45,7 +45,7 @@ namespace ActionTools
             Wait
         };
 
-        static StringListPair actions;
+        static Tools::StringListPair actions;
 
         IfActionParameterDefinition(const Name &name, QObject *parent);
 
