@@ -1,6 +1,6 @@
 /*
 	Actiona
-	Copyright (C) 2005-2016 Jonathan Mercier-Ganady
+	Copyright (C) 2005 Jonathan Mercier-Ganady
 
 	Actiona is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -79,7 +79,7 @@ namespace ActionTools
 		static unsigned long nativeKey(int key)		{ return mNativeKey[key]; }
 
 	private:
-		static const StringListPair mKeyNames;
+        static const Tools::StringListPair mKeyNames;
 		static bool mInitDone;
 		static unsigned long mNativeKey[KeyCount];
 
