@@ -1,6 +1,6 @@
 /*
     Actiona
-	Copyright (C) 2005-2016 Jonathan Mercier-Ganady
+	Copyright (C) 2005 Jonathan Mercier-Ganady
 
     Actiona is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -31,9 +31,9 @@ namespace Global
 	const int				UPDATE_TIMEOUT =	5000;
     const QString			CONNECTIVITY_URL =	"https://actiona.tools/";
 
-	QString currentOS();
 	QString currentOSType();
 	int currentOSBits();
+    int applicationBits();
 }
 
 #endif // GLOBAL_H
