@@ -1,6 +1,6 @@
 /*
     Actiona
-	Copyright (C) 2005-2016 Jonathan Mercier-Ganady
+	Copyright (C) 2005 Jonathan Mercier-Ganady
 
 	Actiona is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -31,6 +31,8 @@
 #include <QUrlQuery>
 #endif
 
+#include <QSysInfo>
+
 namespace Tools
 {
 	Updater::Updater(QNetworkAccessManager *networkAccessManager, const QUrl &url, int timeout, QObject *parent)
@@ -52,6 +54,7 @@ namespace Tools
 	
 	void Updater::checkForUpdates(const QString &program,
 							const Version &programVersion,
+                            int programBits,
 							FileType fileType,
 							ContainerType containerType,
 							const QString &operatingSystem,
@@ -101,9 +104,12 @@ namespace Tools
             break;
         }
         urlQuery.addQueryItem("osName", operatingSystem);
+        urlQuery.addQueryItem("osVariant", QSysInfo::productType());
+        urlQuery.addQueryItem("osVersion", QSysInfo::productVersion());
         urlQuery.addQueryItem("osBits", QString::number(operatingSystemBits));
         urlQuery.addQueryItem("language", language);
         urlQuery.addQueryItem("program", program);
+        urlQuery.addQueryItem("programBits", QString::number(programBits));
 
         url.setQuery(urlQuery);
 #else
@@ -148,8 +154,15 @@ namespace Tools
         url.addQueryItem("program", program);
 #endif
 
+        QString buildName = ACT_BUILD_NAME;
+
+        if(buildName.isEmpty())
+            buildName.clear();
+        else
+            buildName = "-" ACT_BUILD_NAME;
+
 		QNetworkRequest request(url);
-        request.setRawHeader("User-Agent", QString("%1 %2").arg(program).arg(programVersion.toString()).toLatin1());
+        request.setRawHeader("User-Agent", QString("%1 %2%3").arg(program).arg(programVersion.toString()).arg(buildName).toLatin1());
 		
 		mCurrentReply = mNetworkAccessManager->get(request);
 
